airspeed velocity
=================

**airspeed velocity** (``asv``) is a tool for benchmarking Python
packages over their lifetime.  Runtime, memory consumption and even
custom-computed values may be tracked.  The results are displayed in
an interactive web frontend that requires only a basic static
webserver to host.

.. toctree::
   :maxdepth: 1

   commands.rst
   benchmarks.rst
   asv.conf.json.rst
   env_vars.rst
